@@ -9,9 +9,9 @@ Rv = 462. # specific gas constant for water vapour [J kg^-1 K^-1]
 
 g = 9.81 # gravitational accelleration
 
-# calculate the density from pressure temperature and specific humidity
-def rhov(T,p,qv=0.):
-    R = Rd*(1.-qv) + Rv*qv
+def rhov(T,p,sh=0.):
+    '''purpose: calculate the density from pressure temperature and specific humidity'''
+    R = Rd*(1.-sh) + Rv*sh
     return p/R/T
 
 def t_from_theta(ptemp,pressure):
