@@ -1,5 +1,5 @@
 #!/usr/bin/python
-# Filename: radiation.py
+# Filename: humidity.py
 
 from numpy import log10,exp
 
@@ -52,9 +52,9 @@ def mixr2ea(P,mixr):
     '''
     return P*mixr/(0.622+ea)
 
-# not tested
 def ah2mixr (rhov,p,T):
     '''conversion from absolute humidity (units [kg/m**3]) to mixing ratio (units also [kg/kg])
+       not tested
     '''
     return (Rd * T)/(p/rhov-Rv*T)
 
@@ -64,3 +64,9 @@ def wvap2sh(e,p):
     '''
     return eps*e/(p-(1.-eps)*e)
 
+def rh2ah(RH,p,T):
+    '''conversion relative humidity to absolute humidity (kg Water per m^3 Air)'''
+        mixr=rh2mixr(RH, p,T)
+        sh=mixr2sh(mixr)
+        return  sh*rhov(T,p,sh) 
+
